@@ -1,5 +1,5 @@
 package Dist::Build::ShareDir;
-$Dist::Build::ShareDir::VERSION = '0.015';
+$Dist::Build::ShareDir::VERSION = '0.016';
 use strict;
 use warnings;
 
@@ -11,9 +11,9 @@ use File::Spec::Functions qw/abs2rel catfile/;
 sub add_methods {
 	my ($self, $planner) = @_;
 
-	$self->add_delegate($planner, 'dist_sharedir', sub {
-		my ($dir, $dist_name) = @_;
-		$dist_name //= $planner->dist_name;
+	$planner->add_delegate('dist_sharedir', sub {
+		my ($planner, $dir, $dist_name) = @_;
+		$dist_name //= $planner->distribution;
 
 		my @outputs;
 		find(sub {
@@ -23,15 +23,12 @@ sub add_methods {
 			push @outputs, $output;
 		}, $dir);
 
-		ExtUtils::Builder::Node->new(
-			target       => 'code',
-			dependencies => \@outputs,
-			phony        => 1,
-		);
+		$planner->create_phony('code', @outputs);
 	});
 
-	$self->add_delegate($planner, 'module_sharedir', sub {
-		my ($dir, $module_name) = @_;
+	$planner->add_delegate('module_sharedir', sub {
+		my ($planner, $dir, $module_name) = @_;
+		$module_name //= $planner->main_module;
 		(my $module_dir = $module_name) =~ s/::/-/g;
 
 		my @outputs;
@@ -42,11 +39,7 @@ sub add_methods {
 			push @outputs, $output;
 		}, $dir);
 
-		ExtUtils::Builder::Node->new(
-			target       => 'code',
-			dependencies => \@outputs,
-			phony        => 1,
-		);
+		$planner->create_phony('code', @outputs);
 	});
 }
 
@@ -66,7 +59,7 @@ Dist::Build::ShareDir - Sharedir support for Dist::Build
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -78,13 +71,13 @@ version 0.015
 
 This Dist::Build extension implements sharedirs. It does not take any arguments at loading time, and exposts two functions to the planner:
 
-=head2 dist_sharedir($dir, $dist_name)
+=head2 dist_sharedir($dir, $distribution)
 
-This marks C<$dir> as the source sharedir for the distribution C<$dist_name>. If C<$dist_name> isn't given, it defaults to the C<dist_name> of the planner.
+This marks C<$dir> as the source sharedir for the distribution C<$distribution>. If C<$distribution> isn't given, it defaults to the C<distribution> of the planner.
 
 =head2 module_sharedir($dir, $module_name)
 
-This marks C<$dir> as the source sharedir for the module C<$module_name>.
+This marks C<$dir> as the source sharedir for the module C<$module_name>. If C<$module_name> isn't given, it defaults to the C<main_module> of the planner.
 
 =head1 AUTHOR
 
