@@ -1,5 +1,5 @@
 package Dist::Build::XS;
-$Dist::Build::XS::VERSION = '0.015';
+$Dist::Build::XS::VERSION = '0.016';
 use strict;
 use warnings;
 
@@ -33,10 +33,10 @@ sub add_methods {
 			$xs_file = $args{file};
 			$module_name = $planner->module_for_xs($xs_file, $xs_base);
 		} else {
-			$module_name = $planner->main_module_name;
+			$module_name = $planner->main_module;
 			$xs_file = catfile($xs_base, split /::/, $module_name) . '.xs';
 		}
-		my $module_version = $args{version} // $planner->dist_version;
+		my $module_version = $args{version} // $planner->distribution_version;
 
 		$planner = $planner->new_scope;
 
@@ -122,7 +122,7 @@ Dist::Build::XS - An XS implementation for Dist::Build
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -149,7 +149,7 @@ This method takes the following named arguments, all optional:
 
 =item * module
 
-The name of the module to be compiled. This defaults to C<$main_module_name> unless C<file> is given, in which case the name is derived from the path.
+The name of the module to be compiled. This defaults to C<$main_module> unless C<file> is given, in which case the name is derived from the path.
 
 =item * version
 
